@@ -1,4 +1,6 @@
 # -*- mode: perl; perl-indent-level: 2; -*-
+# vim: ts=8 sw=2 sts=2 noexpandtab
+
 # Memoize.pm
 #
 # Transparent memoization of idempotent functions
@@ -8,7 +10,7 @@
 # same terms as Perl itself.
 
 package Memoize;
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 # Compile-time constants
 sub SCALAR () { 0 } 
@@ -44,7 +46,7 @@ sub memoize {
   my $fn = shift;
   my %options = @_;
   my $options = \%options;
-  
+
   unless (defined($fn) && 
 	  (ref $fn eq 'CODE' || ref $fn eq '')) {
     croak "Usage: memoize 'functionname'|coderef {OPTIONS}";
@@ -76,7 +78,7 @@ sub memoize {
   if (defined $normalizer  && ! ref $normalizer) {
     $normalizer = _make_cref($normalizer, $uppack);
   }
-  
+
   my $install_name;
   if (defined $options->{INSTALL}) {
     # INSTALL => name
@@ -131,9 +133,12 @@ sub memoize {
   # Perhaps I should check here that you didn't supply *both* merge
   # options.  But if you did, it does do something reasonable: They
   # both get merged to the same in-memory hash.
-  if ($options{SCALAR_CACHE} eq 'MERGE' || $options{LIST_CACHE} eq 'MERGE') {
+  if ($options{SCALAR_CACHE} eq 'MERGE') {
     $options{MERGED} = 1;
     $caches{SCALAR} = $caches{LIST};
+  } elsif ($options{LIST_CACHE} eq 'MERGE') {
+    $options{MERGED} = 1;
+    $caches{LIST} = $caches{SCALAR};
   }
 
   # Now deal with the TIE options
@@ -144,7 +149,7 @@ sub memoize {
       _my_tie($context, $caches{$context}, $options);  # Croaks on failure
     }
   }
-  
+
   # We should put some more stuff in here eventually.
   # We've been saying that for several versions now.
   # And you know what?  More stuff keeps going in!
@@ -170,7 +175,7 @@ sub _my_tie {
 
   # We already checked to make sure that this works.
   my $shortopt = (ref $fullopt) ? $fullopt->[0] : $fullopt;
-  
+
   return unless defined $shortopt && $shortopt eq 'TIE';
   carp("TIE option to memoize() is deprecated; use HASH instead")
       if $^W;
@@ -213,7 +218,7 @@ sub _memoizer {
   my $orig = shift;		# stringized version of ref to original func.
   my $info = $memotable{$orig};
   my $normalizer = $info->{N};
-  
+
   my $argstr;
   my $context = (wantarray() ? LIST : SCALAR);
 
@@ -270,7 +275,7 @@ sub unmemoize {
   unless (exists $revmemotable{$cref}) {
     croak "Could not unmemoize function `$f', because it was not memoized to begin with";
   }
-  
+
   my $tabent = $memotable{$revmemotable{$cref}};
   unless (defined $tabent) {
     croak "Could not figure out how to unmemoize function `$f'";
@@ -281,8 +286,8 @@ sub unmemoize {
     local($^W) = 0;	       # ``Subroutine $install_name redefined at ...''
     *{$name} = $tabent->{U}; # Replace with original function
   }
-  undef $memotable{$revmemotable{$cref}};
-  undef $revmemotable{$cref};
+  delete $memotable{$revmemotable{$cref}};
+  delete $revmemotable{$cref};
 
   # This removes the last reference to the (possibly tied) memo tables
   # my ($old_function, $memotabs) = @{$tabent}{'U','S','L'};
