@@ -3,7 +3,7 @@ package Memoize::Expire;
 # require 5.00556;
 use Carp;
 use vars qw($DEBUG);
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 # This package will implement expiration by prepending a fixed-length header
 # to the font of the cached data.  The format of the header will be:
@@ -43,7 +43,7 @@ sub TIEHASH {
   }
   $args{LIFETIME} ||= 0;
   $args{NUM_USES} ||= 0;
-  $args{C} = \%cache;
+  $args{C} = delete $args{HASH} || \%cache;
   bless \%args => $package;
 }
 
