@@ -1,11 +1,10 @@
 package Memoize::Storable;
 
 use Storable ();
-$VERSION = '1.04';
+$VERSION = '1.05';
 $Verbose = 0;
 
 sub TIEHASH {
-  require Carp if $Verbose;
   my $package = shift;
   my $filename = shift;
   my $truehash = (-e $filename) ? Storable::retrieve($filename) : {};
@@ -21,31 +20,27 @@ sub TIEHASH {
 }
 
 sub STORE {
-  require Carp if $Verbose;
   my $self = shift;
   print STDERR "Memoize::Storable::STORE(@_)\n" if $Verbose;
   $self->{H}{$_[0]} = $_[1];
 }
 
 sub FETCH {
-  require Carp if $Verbose;
   my $self = shift;
   print STDERR "Memoize::Storable::FETCH(@_)\n" if $Verbose;
   $self->{H}{$_[0]};
 }
 
 sub EXISTS {
-  require Carp if $Verbose;
   my $self = shift;
   print STDERR "Memoize::Storable::EXISTS(@_)\n" if $Verbose;
   exists $self->{H}{$_[0]};
 }
 
 sub DESTROY {
-  require Carp if $Verbose;
   my $self= shift;
   print STDERR "Memoize::Storable::DESTROY(@_)\n" if $Verbose;
-  if ($self->{OPTIONS}{'nstore'}) {
+  if (exists $self->{OPTIONS}{'nstore'}) {
     Storable::nstore($self->{H}, $self->{FILENAME});
   } else {
     Storable::store($self->{H}, $self->{FILENAME});
